@@ -1,19 +1,20 @@
 """
-    Copyright (C) 2023  Michael Ablassmeier <abi@grinser.de>
+Copyright (C) 2023  Michael Ablassmeier <abi@grinser.de>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
+
 import os
 import sys
 import zlib
@@ -81,7 +82,9 @@ class target:
         def write(self, data: bytes) -> int:
             """Write wrapper"""
             self.chksum = zlib.adler32(data, self.chksum)
-            return self.fileHandle.write(data)
+            written = self.fileHandle.write(data)
+            assert written == len(data)
+            return written
 
         def read(self, size=-1) -> int:
             """Read wrapper"""
